Creates a mock cdm with two default synthetic cohorts, one is the index cohort and the other one is the marker cohort. However the users could specify them should they wish.
Examples
# \donttest{
library(CohortSymmetry)
cdm <- mockCohortSymmetry()
cdm
#>
#> ── # OMOP CDM reference (local) of mock database ───────────────────────────────
#> • omop tables: cdm_source, concept, concept_ancestor, concept_relationship,
#> concept_synonym, drug_strength, observation_period, person, vocabulary
#> • cohort tables: cohort_1, cohort_2
#> • achilles tables: -
#> • other tables: -
CDMConnector::cdmDisconnect(cdm = cdm)
# }