Learn R Programming

CohortSymmetry (version 0.2.4)

summariseSequenceRatios: Sequence ratio calculations

Description

Using generateSequenceCohortSet to obtain sequence ratios for the desired outcomes.

Usage

summariseSequenceRatios(cohort, cohortId = NULL, confidenceInterval = 95)

Value

A local table with all the analyses.

Arguments

cohort

A cohort table in the cdm.

cohortId

The Ids in the cohort that are to be included in the analyses.

confidenceInterval

Default is 95, indicating the central 95% confidence interval.

Examples

Run this code
# \donttest{
library(CohortSymmetry)
cdm <- mockCohortSymmetry()
cdm <- generateSequenceCohortSet(cdm = cdm,
                                 name = "joined_cohorts",
                                 indexTable = "cohort_1",
                                 markerTable = "cohort_2")
pssa_result <- summariseSequenceRatios(cohort = cdm$joined_cohorts)
pssa_result
CDMConnector::cdmDisconnect(cdm)
# }

Run the code above in your browser using DataLab