mockCohortSymmetry: Creates mock cdm object for testing
Description
Creates a mock cdm with two default synthetic cohorts,
one is the index cohort and the other one is the marker cohort.
However the users could specify them should they wish.
Usage
mockCohortSymmetry(
seed = 1,
indexCohort = NULL,
markerCohort = NULL,
con = NULL,
schema = "main"
)
Value
A mock cdm object contains your index and marker cohort
Arguments
- seed
The seed to be inputted.
- indexCohort
The tibble of your index cohort.
Default is NULL, which means the default indexCohort is being used.
- markerCohort
The tibble of your marker cohort.
Default is NULL, which means the default markerCohort is being used.
- con
Connection detail.
- schema
Name of your write schema.
Examples
Run this code# \donttest{
library(CohortSymmetry)
cdm <- mockCohortSymmetry()
cdm
CDMConnector::cdmDisconnect(cdm = cdm)
# }
Run the code above in your browser using DataLab