Learn R Programming

CohortSymmetry (version 0.2.4)

tableSequenceRatios: A formatted visualization of sequence_symmetry objects.

Description

It provides a formatted table with the contents of the summariseSequenceRatios output.

Usage

tableSequenceRatios(
  result,
  header = "marker_cohort_name",
  groupColumn = "cdm_name",
  type = "gt",
  hide = "variable_level"
)

Value

A formatted version of the sequence_symmetry object.

Arguments

result

A sequence_symmetry object.

header

A vector specifying the elements to include in the header. See visOmopResults package for more information on how to use this parameter.

groupColumn

Columns to use as group labels. See visOmopResults package for more information on how to use this parameter.

type

The desired format of the output table.

hide

Columns to drop from the output table.

Examples

Run this code
# \donttest{
library(CohortSymmetry)
cdm <- mockCohortSymmetry()
cdm <- generateSequenceCohortSet(cdm = cdm,
                                 indexTable = "cohort_1",
                                 markerTable = "cohort_2",
                                 name = "joined_cohort")
res <- summariseSequenceRatios(cohort = cdm$joined_cohort)
gtResult <- tableSequenceRatios(res)
CDMConnector::cdmDisconnect(cdm = cdm)
# }

Run the code above in your browser using DataLab